echo off
cls
rem  Copyright (c) Oracle Corporation 1993.  All Rights Reserved, Worldwide.
rem
rem  NAME
rem    cert-maker.bat  - Creates a certificate, public, and private keys.
rem
rem  FUNCTION
rem    This is the java code signing generating script.
rem    Following components are created: 
rem       - USER identity key
rem       - USER public/private key pair
rem       - USER x509 ceritificate
rem 
rem
rem --------------------------------------------
rem set the parameters here for the certificate
rem --------------------------------------------
set USER=%1%
set DIRECTIVE=%USER%\certdirective
set PUBKEY=%USER%\pub_%USER%
set PRVKEY=%USER%\priv_%USER%
set CERTIFICATE=%USER%.x509

rem -----------------------------------
rem creating all the elements from here
rem -----------------------------------

echo. 
echo Certificate and Identity Maker v1.0
echo.

if(%1%) == () goto usage

echo.
echo Creating directory for %USER%
echo.

echo "Creating the signer and certificate"
echo.

echo.
echo Removing existing %USER% identify if present ....
javakey -r %USER%
echo.

echo.
echo Creating the the %USER% identity key, as a trusted identity.
javakey -cs %USER% True
echo.

echo.
echo Creating the public and private keys for %USER%
echo Storing the public key in %PUBKEY%
echo Storing the private key in %PRVKEY%
javakey -gk %USER% DSA 512 %PUBKEY% %PRVKEY% 
echo.

echo.
echo Generating an x509 certificate for %USER%, and store it in the file named %CERTIFICATE%. 
echo This output file name is given in the directive file %DIRECTIVE%. 
javakey -gc %DIRECTIVE%
echo.

rem echo Importing the certificate %CERTIFICATE% 
rem javakey -ic %USER% %CERTIFICATE%

rem -------------------------
rem do some directory cleanup
rem -------------------------
copy %CERTIFICATE% %USER%
del %CERTIFICATE%


echo -----------------------------------------
echo Results of the operation for User: %USER%
echo -----------------------------------------
javakey -ld

goto done

:usage

echo.
echo Usage: cert-maker USER
echo.

:done
