@echo off
cls
rem
rem Windows NT batch script to compile a PJC
rem Compiles the PJC source into the classes directory
rem
rem sbutton 10/24/1999  created
rem drmills 04/10/2000  Now reads a file called pjc.properties to 
rem                     provide configuration information.
rem                     allowing this batch file to be generic
rem drmills 02/06/2001  Enhanced to sign and deploy PJCs as well 
rem

@echo ----------------------------------------------------------------------
@echo.
@echo MAKEPJC version 1.2
@echo.
@echo This batch script will compile the classes associated with this PJC and 
@echo create a new JAR file which can be deployed with Oracle Forms Server.
@echo.
@echo The class files will be compiled into the classes directory. The JAR 
@echo file will also be created and stored in the classes directory
@echo The JAR file can also be signed and deployed.  To Deploy the JAR you 
@echo must supply the deployment directory as an argument to this batch file
@echo.
@echo The Javadoc documentation will be re-generated based on the source code.
@echo.
@echo -----------------------------------------------------------------------
@echo.


rem set the requisite variables from the pjc.properties file

for /F "eol=# tokens=1,2* delims==" %%i in (pjc.properties) do set %%i=%%j


rem check the Environment

if "%JDK_HOME%" NEQ "" goto got_jdk_home
SET /P JDK_HOME="Enter the directory where a %PJC_JDK_VER% JDK is installed: "
if "%JDK_HOME%"=="" goto usage

if "%ORACLE_HOME%" NEQ "" goto got_oracle_home
SET /P ORACLE_HOME="Enter the ORACLE_HOME where FORMS is installed: "
if "%ORACLE_HOME%"=="" goto usage

:GOT_ORACLE_HOME
:GOT_JDK_HOME



SETLOCAL
set CLASSPATH=.;%ORACLE_HOME%\%FORMSDIR%\java;%CLASSPATH%

rem compile the Java source
@echo -----------------------------------------------------------------------
@echo Compiling %PJCNAME% into %CLASSDIR%
@echo -----------------------------------------------------------------------

for %%f in (%SOURCEDIR%\*.java) do "%JDK_HOME%\bin\javac" -d %CLASSDIR% %%f

rem create the JAR file
@echo.
@echo -----------------------------------------------------------------------
@echo Recreating JAR file %JARFILE%
@echo -----------------------------------------------------------------------
pushd %CLASSDIR%
"%JDK_HOME%\bin\jar" cvf %JARFILE% %JARROOT%\*
popd

if /I "%SIGN_PJC%" NEQ "TRUE" goto UNSIGNED
@echo.
@echo -----------------------------------------------------------------------
@echo Signing JAR file %JARFILE% (%JARFILE%.sig)
@echo -----------------------------------------------------------------------

pushd %CLASSDIR%
javakey -gs %SIGN_DIRECTIVE% %JARFILE% 
popd

:UNSIGNED


if "%1%" == "" goto NODEPLOY
pushd %CLASSDIR%

@echo.
@echo -----------------------------------------------------------------------
@echo Deploying to %1
@echo -----------------------------------------------------------------------

if /I "%DEPLOY_WHICH%" == "ALL" goto DEPLOY_ALL
if /I "%DEPLOY_WHICH%" == "" goto DEPLOY_ALL
if /I "%DEPLOY_WHICH%" NEQ "UNSIGNED" goto DEPLOY_SIGNED
:DEPLOY_ALL
rem copy the unsigned JAR
echo deploying unsigned JAR file 
copy /V /Y %JARFILE% %1%

if /I "%DEPLOY_WHICH%" == "UNSIGNED" goto DEPLOY_FINISHED
:DEPLOY_SIGNED
rem copy the signed JAR
echo deploying signed JAR file 
copy /V /Y %JARFILE%.sig %1%
:DEPLOY_FINISHED
popd

:NODEPLOY


rem create the Javadoc file
@echo -----------------------------------------------------------------------
@echo Recreating the Javadoc into %DOCDIR%
@echo -----------------------------------------------------------------------
"%JDK_HOME%\bin\javadoc" -author -version -d %DOCDIR% %PJCPACKAGE%

:ENDLOCAL

@echo.
@echo -----------------------------------------------------------------------
@echo MAKEPJC for %PJCNAME% Complete
@echo -----------------------------------------------------------------------

goto done

@echo on
:usage
@echo.
@echo ----------------------------------------------------------------------
@echo Following are the requirements to run this script 
@echo    set JDK_HOME to a version %PJC_JDK_VER% Java Development Kit Home
@echo    set ORACLE_HOME to location of the Forms software installation
@echo    (optional) supply a directory for JAR deployment on the command line
@echo -----------------------------------------------------------------------

:done
