package oracle.forms.demos.uploadserver;

import sun.misc.BASE64Decoder;
import java.io.FileOutputStream;
import java.io.DataOutputStream;
import java.io.DataInputStream;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.zip.*;
import java.io.File;

/**
 * This class performs the task of assisting with the conversion of BASE64 encoded
 * data and the subsequent storage in a file.  This class was designed primarily
 * for use from the Forms 6<i>i</i> Java Importer in conjunction with the
 * FileUploader JavaBean.
 * <P>The FileUploader JavaBean returns BASE64 encoded data in
 * a series of 4K chunks which need to be reassembled into a contiguous string for
 * use in the decoding process.  This class enables a Form to store the chunks
 * of data it receives with the addChunk() method and then to decode the chunks
 * using the decodeBuffer() method.
 * <P>The Byte stream of the uploaded file may have been compressed before uploading
 * so the decodeBuffer() method takes care of that as well
 *
 * @version 1.1
 * @date 10-05-2001
 * @author Steve Button
 * @author Duncan Mills
 */

public class FormsDecoder
{
  /**
   * Used to store the chunks as they are added.
   */
  private StringBuffer buffer;

  /**
   * The BASE64 encoder used to convert the data back to it's original format.
   */
  private BASE64Decoder DECODER = new BASE64Decoder();

  /**
   * Create a new FormsDecoder object.  This operation initialises the
   * buffer used to store the fragments.
   */
  public FormsDecoder()
  {
    System.out.println("FormsDecoder");
    buffer = new StringBuffer();
  }

  /**
   * Appends a chunk of data to the end of the buffer.
   *
   * @param data the chunk of data to be appended to the buffer.
   */
  public void addChunk(String data)
  {
    buffer.append(data);
  }
  /**
   * Convert the data that has been added to the buffer via the addChunk method
   * to it's original format using sun.misc.BASE64Decoder and write it out to the
   * specified filename.
   *
   * @param filename the file to create for the decoded data.
   * @param filesize the size of the uploaded file
   * @param isCompressed indicator that we need to unzip the file
   * @throws IOException
   * @throws FormsDecoderException
   */
  public void decodeBuffer(String directoryName, String fileName, int filesize, boolean isCompressed) throws IOException, FormsDecoderException
  {

    if(buffer.length()==0)
      throw(new FormsDecoderException("no data in the buffer to decode"));

    FileOutputStream fos = new FileOutputStream(new File(directoryName,fileName));
    byte[] decoded = DECODER.decodeBuffer(buffer.toString());
    byte[] decompressedArray = new byte[0];
    if (isCompressed)
    {
      ByteArrayInputStream bais = new ByteArrayInputStream(decoded);
      GZIPInputStream gis = new GZIPInputStream(bais);
      DataInputStream dis = new DataInputStream(gis);
      decompressedArray = new byte[filesize];
      dis.readFully(decompressedArray);
      fos.write(decompressedArray);
    }
    else
    {
      fos.write(decoded);
    }
    fos.close();

    // reset the variable to try and free them up
    decoded=new byte[0];
    decompressedArray = new byte[0];
    buffer=new StringBuffer();
    Runtime.getRuntime().runFinalization();
  };


}
